package de.intevation.flys.artifacts.access;

import gnu.trove.TIntArrayList;

import org.apache.log4j.Logger;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.states.SoundingsSelect;


public class BedHeightAccess extends Access {

    private static final Logger logger = Logger.getLogger(BedHeightAccess.class);

    private int[] singleIDs;
    private int[] epochIDs;

    private Double lowerKM;
    private Double upperKM;


    public BedHeightAccess(FLYSArtifact artifact) {
        super(artifact);
    }


    public Double getLowerKM() {
        if (lowerKM == null) {
            lowerKM = getDouble("ld_from");
        }

        return lowerKM;
    }


    public Double getUpperKM() {
        if (upperKM == null) {
            upperKM = getDouble("ld_to");
        }

        return upperKM;
    }


    public int[] getBedHeightSingleIDs() {
        if (singleIDs == null) {
            String data = getString("soundings");

            if (data == null) {
                logger.warn("No 'soundings' parameter specified!");
                return null;
            }

            String[] parts = data.split(";");

            TIntArrayList ids = new TIntArrayList();

            for (String part: parts) {
                if (part.indexOf(SoundingsSelect.PREFIX_SINGLE) >= 0) {
                    String tmp = part.replace(SoundingsSelect.PREFIX_SINGLE, "");

                    try {
                        ids.add(Integer.parseInt(tmp));
                    }
                    catch (NumberFormatException nfe) {
                        logger.warn("Cannot parse int from string: '" + tmp + "'");
                    }
                }
            }

            singleIDs = ids.toNativeArray();
        }

        return singleIDs;
    }


    public int[] getBedHeightEpochIDs() {
        if (epochIDs == null) {
            String data = getString("soundings");

            if (data == null) {
                logger.warn("No 'soundings' parameter specified!");
                return null;
            }

            String[] parts = data.split(";");

            TIntArrayList ids = new TIntArrayList();

            for (String part: parts) {
                if (part.indexOf(SoundingsSelect.PREFIX_EPOCH) >= 0) {
                    String tmp = part.replace(SoundingsSelect.PREFIX_EPOCH, "");

                    try {
                        ids.add(Integer.parseInt(tmp));
                    }
                    catch (NumberFormatException nfe) {
                        logger.warn("Cannot parse int from string: '" + tmp + "'");
                    }
                }
            }

            epochIDs = ids.toNativeArray();
        }

        return epochIDs;
    }
}
